BeforeSendLogCallback typedef

BeforeSendLogCallback = FutureOr<SentryLog?> Function(SentryLog log, Hint hint)

This function is called right before a log is about to be sent. Can return a modified log or null to drop the log.

Implementation

typedef BeforeSendLogCallback =
    FutureOr<SentryLog?> Function(SentryLog log, Hint hint);