ISentrySpan class abstract

Represents performance monitoring Span.

Implementers

Constructors

ISentrySpan()

Properties

context → SentrySpanContext
Gets the span context.
no setter
endTimestamp → DateTime?
Returns the end timestamp if finished
no setter
finished → bool
Returns true if span is finished
no setter
hashCode → int
The hash code for this object.
no setterinherited
origin ↔ String?
Gets the span origin
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp → DateTime
Returns the star timestamp
no setter
status ↔ SpanStatus?
Gets span status.
getter/setter pair
throwable ↔ dynamic
Returns the associated error
getter/setter pair

Methods

finish({SpanStatus? status, DateTime? endTimestamp, Hint? hint}) → Future<void>
Sets span timestamp marking this span as finished.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeData(String key) → void
Removes extra data on span or transaction.
removeTag(String key) → void
Removes the tag on span or transaction.
setData(String key, dynamic value) → void
Sets extra data on span or transaction.
setMeasurement(String name, num value, {SentryMeasurementUnit? unit}) → void
Set observed measurement for this span or transaction.
setTag(String key, String value) → void
Sets the tag on span or transaction.
startChild(String operation, {String? description, DateTime? startTimestamp}) → ISentrySpan
Starts a child Span.
toBaggageHeader() → SentryBaggageHeader?
Returns the baggage that can be sent as "baggage" header.
toSentryTrace() → SentryTraceHeader
Returns the trace information that could be sent as a sentry-trace header.
toString() → String
A string representation of this object.
inherited
traceContext() → SentryTraceContextHeader?
Returns the trace context.

Operators

operator ==(Object other) → bool
The equality operator.
inherited