Integration<T extends SentryOptions> class abstract

Code that provides middlewares, bindings or hooks into certain frameworks or environments, along with code that inserts those bindings and activates them.

Implementers

Constructors

Integration()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Hub hub, T options) → FutureOr<void>
A Callable method for the Integration interface
close() → FutureOr<void>
NoOp by default : only closeable integrations need to override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited