MaxRequestBodySize enum

Describes the size of http request bodies which should be added to an event

Inheritance
Available extensions

Values

never → const MaxRequestBodySize

Request bodies are never sent

small → const MaxRequestBodySize

Only small request bodies will be captured where the cutoff for small depends on the SDK (typically 4KB)

medium → const MaxRequestBodySize

Medium and small requests will be captured (typically 10KB)

always → const MaxRequestBodySize

The SDK will always capture the request body for as long as Sentry can make sense of it

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldAddBody(int contentLength) → bool

Available on MaxRequestBodySize, provided by the MaxRequestBodySizeX extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MaxRequestBodySize>
A constant List of the values in this enum, in order of their declaration.