NoOpSentrySpanV2 class final

Implemented types

Constructors

NoOpSentrySpanV2({RecordingSentrySpanV2? recordingParent, bool isIgnored = false})
const

Properties

attributes Map<String, SentryAttribute>
The read-only view of the attributes of this span using Map.unmodifiable.
no setteroverride
endTimestamp DateTime?
The end timestamp of this span.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isEnded bool
Whether this span has ended.
no setteroverride
name String
The name of this span.
finalgetter/setter pairoverride
parentSpan SentrySpanV2?
The parent span of this span.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spanId SpanId
The id of this span.
no setteroverride
startTimestamp DateTime
The start timestamp of this span.
no setteroverride
status SentrySpanStatusV2
The status of this span.
finalgetter/setter pairoverride
traceId SentryId
The id of the trace this span belongs to.
no setteroverride

Methods

end({DateTime? endTimestamp}) → void
Ends this span.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttribute(String key) → void
Removes an attribute on this span with a matching key.
override
setAttribute(String key, SentryAttribute value) → void
Sets an attribute on this span, replacing any existing attribute with the same key.
override
setAttributes(Map<String, SentryAttribute> attributes) → void
Sets attributes on this span, replacing existing attributes with the same keys.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

instance → const NoOpSentrySpanV2