end method

  1. @override
void end({
  1. DateTime? endTimestamp,
})
override

Ends this span.

endTimestamp can be used to override the end time. If omitted, this span ends using the current time when end is executed.

Implementation

@override
void end({DateTime? endTimestamp}) {}