setAttribute method
Sets an attribute on this span, replacing any existing attribute with the same key.
Implementation
@override
void setAttribute(String key, SentryAttribute value) {}
Sets an attribute on this span, replacing any existing attribute with the same key.
@override
void setAttribute(String key, SentryAttribute value) {}