setAttributes method
Sets attributes on this span, replacing existing attributes with the same keys.
Implementation
@override
void setAttributes(Map<String, SentryAttribute> attributes) {
_attributes.addAll(attributes);
}
Sets attributes on this span, replacing existing attributes with the same keys.
@override
void setAttributes(Map<String, SentryAttribute> attributes) {
_attributes.addAll(attributes);
}