SdkInfo class

An object describing the system SDK.

Constructors

SdkInfo({String? sdkName, int? versionMajor, int? versionMinor, int? versionPatchlevel, Map<String, dynamic>? unknown})
SdkInfo.fromJson(Map<String, dynamic> data)
Deserializes a SdkInfo from JSON Map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkName ↔ String?
getter/setter pair
versionMajor ↔ int?
getter/setter pair
versionMinor ↔ int?
getter/setter pair
versionPatchlevel ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited