SentryApp class

App context describes the application.

As opposed to the runtime, this is the actual application that was running and carries metadata about the current session.

Constructors

SentryApp({String? name, String? version, String? identifier, String? build, String? buildType, DateTime? startTime, String? deviceAppHash, int? appMemory, bool? inForeground, List<String>? viewNames, double? textScale, Map<String, dynamic>? unknown})
SentryApp.fromJson(Map<String, dynamic> data)
Deserializes a SentryApp from JSON Map.
factory

Properties

appMemory int?
Amount of memory used by the application in bytes.
getter/setter pair
build String?
Internal build identifier, as it appears on the platform.
getter/setter pair
buildType String?
String identifying the kind of build, e.g. testflight.
getter/setter pair
deviceAppHash String?
Application specific device identifier.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String?
Version-independent application identifier, often a dotted bundle ID.
getter/setter pair
inForeground bool?
A flag indicating whether the app is in foreground or not. An app is in foreground when it's visible to the user.
getter/setter pair
name String?
Human readable application name, as it appears on the platform.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime?
When the application was started by the user.
getter/setter pair
textScale double?
The current text scale. Only available on Flutter.
getter/setter pair
version String?
Human readable application version, as it appears on the platform.
getter/setter pair
viewNames List<String>?
The names of the currently visible views.
getter/setter pair

Methods

clone() SentryApp
copyWith({String? name, String? version, String? identifier, String? build, String? buildType, DateTime? startTime, String? deviceAppHash, int? appMemory, bool? inForeground, List<String>? viewNames, double? textScale}) SentryApp
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

type → const String