externalStorageSize property
Total size of an attached external storage in bytes (e.g.: android SDK card).
Implementation
int? externalStorageSize;
Total size of an attached external storage in bytes (e.g.: android SDK card).
int? externalStorageSize;