type property

String? type
getter/setter pair

The event type determines how Sentry handles the event and has an impact on processing, rate limiting, and quotas. defaults to 'default'

Implementation

String? type;