SentryFeedback class

Constructors

SentryFeedback({required String message, String? contactEmail, String? name, String? replayId, String? url, SentryId? associatedEventId, Map<String, dynamic>? unknown})
SentryFeedback.fromJson(Map<String, dynamic> data)
Deserializes a SentryFeedback from JSON Map.
factory

Properties

associatedEventId ↔ SentryId?
getter/setter pair
contactEmail ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
name ↔ String?
getter/setter pair
replayId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

type → const String