SentryLogAttribute class
- Inheritance
-
- Object
- SentryAttribute
- SentryLogAttribute
- Annotations
-
- @Deprecated('Use SentryAttribute instead')
Constructors
- SentryLogAttribute.bool(bool value)
-
factory
- SentryLogAttribute.double(double value)
-
factory
- SentryLogAttribute.int(int value)
-
factory
- SentryLogAttribute.string(String value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited