SentryMetricUnit class abstract final

String constants for metric units.

These constants represent the API names of measurement units that can be used with metrics.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bit → const String
Bit, corresponding to 1/8 of a byte.
byte → const String
Byte.
day → const String
Day, 86,400 seconds.
exabyte → const String
Exabyte, 10^18 bytes.
exbibyte → const String
Exbibyte, 2^60 bytes.
gibibyte → const String
Gibibyte, 2^30 bytes.
gigabyte → const String
Gigabyte, 10^9 bytes.
hour → const String
Hour, 3600 seconds.
kibibyte → const String
Kibibyte, 2^10 bytes.
kilobyte → const String
Kilobyte, 10^3 bytes.
mebibyte → const String
Mebibyte, 2^20 bytes.
megabyte → const String
Megabyte, 10^6 bytes.
microsecond → const String
Microsecond, 10^-6 seconds.
millisecond → const String
Millisecond, 10^-3 seconds.
minute → const String
Minute, 60 seconds.
nanosecond → const String
Nanosecond, 10^-9 seconds.
pebibyte → const String
Pebibyte, 2^50 bytes.
percent → const String
Ratio expressed as a fraction of 100. 100% equals a ratio of 1.0.
petabyte → const String
Petabyte, 10^15 bytes.
ratio → const String
Floating point fraction of 1.
second → const String
Full second.
tebibyte → const String
Tebibyte, 2^40 bytes.
terabyte → const String
Terabyte, 10^12 bytes.
week → const String
Week, 604,800 seconds.