kernelVersion property
An independent kernel version string.
This is typically the entire output of the uname syscall.
Implementation
String? kernelVersion;
An independent kernel version string.
This is typically the entire output of the uname syscall.
String? kernelVersion;