url property
The URL of the request if available. The query string can be declared either as part of the url, or separately in queryString.
Implementation
String? url;
The URL of the request if available. The query string can be declared either as part of the url, or separately in queryString.
String? url;