SentryRuntime class

Describes a runtime in more detail.

Typically this context is used multiple times if multiple runtimes are involved (for instance if you have a JavaScript application running on top of JVM).

Constructors

SentryRuntime({String? key, String? name, String? version, String? compiler, String? rawDescription, String? build, Map<String, dynamic>? unknown})
SentryRuntime.fromJson(Map<String, dynamic> data)
Deserializes a SentryRuntime from JSON Map.
factory

Properties

build ↔ String?
Application build string, if it is separate from the version.
getter/setter pair
compiler ↔ String?
Dart has a couple different compilers. E.g: dart2js, dartdevc, AOT, VM
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Key used in the JSON and which will be displayed in the Sentry UI. Defaults to lower case version of name.
getter/setter pair
name ↔ String?
The name of the runtime.
getter/setter pair
rawDescription ↔ String?
An unprocessed description string obtained by the runtime.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
The version identifier of the runtime.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

listType → const String
type → const String