SentrySpanStatusV2 enum

Inheritance
Available extensions

Values

error → const SentrySpanStatusV2
const SentrySpanStatusV2('error')
cancelled → const SentrySpanStatusV2
const SentrySpanStatusV2('cancelled')
deadlineExceeded → const SentrySpanStatusV2
const SentrySpanStatusV2('deadline_exceeded')
ok → const SentrySpanStatusV2
const SentrySpanStatusV2('ok')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SentrySpanStatusV2>
A constant List of the values in this enum, in order of their declaration.