SentrySpanV2 class sealed

Represents a basic telemetry span.

Implementers

Properties

attributes Map<String, SentryAttribute>
The read-only view of the attributes of this span using Map.unmodifiable.
no setter
endTimestamp DateTime?
The end timestamp of this span.
no setter
hashCode int
The hash code for this object.
no setterinherited
isEnded bool
Whether this span has ended.
no setter
name String
The name of this span.
getter/setter pair
parentSpan SentrySpanV2?
The parent span of this span.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spanId SpanId
The id of this span.
no setter
startTimestamp DateTime
The start timestamp of this span.
no setter
status SentrySpanStatusV2
The status of this span.
getter/setter pair
traceId SentryId
The id of the trace this span belongs to.
no setter

Methods

end({DateTime? endTimestamp}) → void
Ends this span.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttribute(String key) → void
Removes an attribute on this span with a matching key.
setAttribute(String key, SentryAttribute value) → void
Sets an attribute on this span, replacing any existing attribute with the same key.
setAttributes(Map<String, SentryAttribute> attributes) → void
Sets attributes on this span, replacing existing attributes with the same keys.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited