setAttributes abstract method
Sets attributes on this span, replacing existing attributes with the same keys.
Implementation
void setAttributes(Map<String, SentryAttribute> attributes);
Sets attributes on this span, replacing existing attributes with the same keys.
void setAttributes(Map<String, SentryAttribute> attributes);