SentryStackFrame class

Frames belong to a StackTrace It should contain at least a filename, function or instruction_addr

Constructors

SentryStackFrame({String? absPath, String? fileName, String? function, String? module, int? lineNo, int? colNo, String? contextLine, bool? inApp, String? package, bool? native, String? platform, String? imageAddr, String? symbolAddr, String? instructionAddr, String? rawFunction, bool? stackStart, String? symbol, List<int>? framesOmitted, List<String>? preContext, List<String>? postContext, Map<String, dynamic>? vars, Map<String, dynamic>? unknown})
SentryStackFrame.fromJson(Map<String, dynamic> data)
Deserializes a SentryStackFrame from JSON Map.
factory

Properties

absPath ↔ String?
The absolute path to filename.
getter/setter pair
colNo ↔ int?
The column number of the call
getter/setter pair
contextLine ↔ String?
Source code in filename at line number.
getter/setter pair
fileName ↔ String?
The relative file path to the call.
getter/setter pair
framesOmitted → List<int>
Which frames were omitted, if any.
no setter
function ↔ String?
The name of the function being called.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageAddr ↔ String?
Optionally an address of the debug image to reference.
getter/setter pair
inApp ↔ bool?
Signifies whether this frame is related to the execution of the relevant code in this stacktrace.
getter/setter pair
instructionAddr ↔ String?
The instruction address The official docs refer to it as 'The difference between instruction address and symbol address in bytes.'
getter/setter pair
lineNo ↔ int?
The column number of the call
getter/setter pair
module ↔ String?
Platform-specific module path.
getter/setter pair
native ↔ bool?
getter/setter pair
package ↔ String?
The "package" the frame was contained in.
getter/setter pair
platform ↔ String?
This can override the platform for a single frame. Otherwise, the platform of the event is assumed. This can be used for multi-platform stack traces
getter/setter pair
postContext → List<String>
An immutable list of source code lines after context_line (in order) – usually lineno + 1:lineno + 5.
no setter
preContext → List<String>
An immutable list of source code lines before context_line (in order) – usually lineno - 5:lineno.
no setter
rawFunction ↔ String?
The original function name, if the function name is shortened or demangled. Sentry shows the raw function when clicking on the shortened one in the UI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackStart ↔ bool?
Marks this frame as the bottom of a chained stack trace.
getter/setter pair
symbol ↔ String?
Potentially mangled name of the symbol as it appears in an executable.
getter/setter pair
symbolAddr ↔ String?
An optional address that points to a symbol. We use the instruction address for symbolication, but this can be used to calculate an instruction offset automatically.
getter/setter pair
vars → Map<String, dynamic>
An immutable mapping of variables which were available within this frame (usually context-locals).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited