name property
The name of the thread. On Dart platforms where Isolates are available, this can be set to Isolate.debugName
Implementation
String? name;
The name of the thread. On Dart platforms where Isolates are available, this can be set to Isolate.debugName
String? name;