SentryTraceContextHeader class

Constructors

SentryTraceContextHeader(SentryId traceId, String publicKey, {String? release, String? environment, String? userId, String? transaction, String? sampleRate, String? sampleRand, String? sampled, Map<String, dynamic>? unknown, SentryId? replayId, String? orgId})
SentryTraceContextHeader.fromBaggage(SentryBaggage baggage)
factory
SentryTraceContextHeader.fromJson(Map<String, dynamic> data)
Deserializes a SentryTraceContextHeader from JSON Map.
factory
SentryTraceContextHeader.fromRecordingSpan(RecordingSentrySpanV2 span, SentryOptions options, SentryId? replayId)
Creates a SentryTraceContextHeader from a RecordingSentrySpanV2.
factory

Properties

environment → String?
final
hashCode → int
The hash code for this object.
no setterinherited
orgId → String?
The organization ID associated with this trace.
final
publicKey → String
final
release → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampled → String?
final
sampleRand → String?
final
sampleRate → String?
final
traceId → SentryId
final
transaction → String?
final
userId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBaggage() → SentryBaggage
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited