SentryTraceLifecycle enum

Controls how trace data is collected and transmitted to Sentry.

Inheritance
Available extensions

Values

stream → const SentryTraceLifecycle

Spans are sent individually as they complete.

Each span is buffered and transmitted independently without waiting for the entire trace to finish.

static → const SentryTraceLifecycle

Spans are buffered and sent as a complete transaction.

All spans in a trace are collected and transmitted together when the root span ends, matching the traditional transaction model.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SentryTraceLifecycle>
A constant List of the values in this enum, in order of their declaration.