attributes property

  1. @override
Map<String, SentryAttribute> get attributes
override

The read-only view of the attributes of this span using Map.unmodifiable.

The returned map must not be mutated by callers.

Implementation

@override
Map<String, SentryAttribute> get attributes => _throw();