Contexts class

The context interfaces provide additional context data.

Typically this is data related to the Device, OS, Runtime, App, Browser, GPU and State context.

See also: https://develop.sentry.dev/sdk/event-payloads/contexts/.

Inheritance

Constructors

Contexts({SentryDevice? device, SentryOperatingSystem? operatingSystem, List<SentryRuntime>? runtimes, SentryApp? app, SentryBrowser? browser, SentryGpu? gpu, SentryCulture? culture, SentryTraceContext? trace, SentryResponse? response, SentryFeedback? feedback})
Contexts.fromJson(Map<String, dynamic> data)
Deserializes Contexts from JSON Map.
factory

Properties

app ↔ SentryApp?
App context describes the application.
getter/setter pair
browser ↔ SentryBrowser?
Carries information about the browser or user agent for web-related errors.
getter/setter pair
culture ↔ SentryCulture?
Culture Context describes certain properties of the culture in which the software is used.
getter/setter pair
device ↔ SentryDevice?
This describes the device that caused the event.
getter/setter pair
entries → Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setterinherited
feedback ↔ SentryFeedback?
Feedback context for a feedback event.
getter/setter pair
gpu ↔ SentryGpu?
GPU context describes the GPU of the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<String>
The keys of this Map.
no setterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
operatingSystem ↔ SentryOperatingSystem?
Describes the operating system on which the event was created.
getter/setter pair
response ↔ SentryResponse?
Response context for a HTTP response.
getter/setter pair
runtimes ↔ List<SentryRuntime>
Describes an immutable list of runtimes in more detail (for instance if you have a Flutter application running on top of Android).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trace ↔ SentryTraceContext?
The tracing context of the transaction
getter/setter pair
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<String, dynamic>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
addRuntime(SentryRuntime runtime) → void
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
clone() → Contexts
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
copyWith({SentryDevice? device, SentryOperatingSystem? operatingSystem, List<SentryRuntime>? runtimes, SentryApp? app, SentryBrowser? browser, SentryCulture? culture, SentryGpu? gpu, SentryTraceContext? trace, SentryResponse? response, SentryFeedback? feedback}) → Contexts
forEach(void action(String key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(String key, dynamic value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeRuntime(SentryRuntime runtime) → void
removeWhere(bool test(String key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() → String
A string representation of this object.
inherited
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(String key, dynamic value)) → void
Updates all values.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(String key, dynamic value) → void
Associates the key with the given value.
inherited