FractionSentryMeasurementUnit enum

Inheritance
Implemented types
Available extensions

Values

ratio → const FractionSentryMeasurementUnit

Floating point fraction of 1.

const FractionSentryMeasurementUnit('ratio')
percent → const FractionSentryMeasurementUnit

Ratio expressed as a fraction of 100. 100% equals a ratio of 1.0.

const FractionSentryMeasurementUnit('percent')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringValue() → String

Available on SentryMeasurementUnit, provided by the SentryMeasurementUnitExtension extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<FractionSentryMeasurementUnit>
A constant List of the values in this enum, in order of their declaration.