IoSentryAttachment class

Inheritance

Constructors

IoSentryAttachment.fromFile(File file, {String? filename, String? attachmentType, String? contentType})
Creates an attachment from a given File. Only available on dart:io platforms. Not available on web.
IoSentryAttachment.fromPath(String path, {String? filename, String? attachmentType, String? contentType})
Creates an attachment from a given path. Only available on dart:io platforms. Not available on web.

Properties

addToTransactions → bool
If true, attachment should be added to every transaction. Defaults to false.
finalinherited
attachmentType → String
Attachment type. Should be one of the static types declared in SentryAttachment.
finalinherited
bytes → FutureOr<Uint8List>
Attachment content. Is loaded while sending this attachment.
no setterinherited
contentType → String?
Attachment content type. Inferred by Sentry if it's not given.
finalinherited
filename → String
Attachment file name.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited