IsolateErrorIntegration class

NoOp web integration : isolate doesnt' work in browser

Inheritance

Constructors

IsolateErrorIntegration()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(Hub hub, SentryOptions options) → void
A Callable method for the Integration interface
override
close() → FutureOr<void>
NoOp by default : only closeable integrations need to override
inherited
handleIsolateError(Hub hub, SentryOptions options, dynamic error) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited