SentryAttachment class

Arbitrary content which gets attached to an event.

Implementers

Constructors

SentryAttachment.fromByteData(ByteData bytes, String fileName, {String? contentType, String? attachmentType, bool? addToTransactions})
Creates an SentryAttachment from ByteData
SentryAttachment.fromIntList(List<int> bytes, String fileName, {String? contentType, String? attachmentType, bool? addToTransactions})
Creates an SentryAttachment from a List<int>
SentryAttachment.fromLoader({required ContentLoader loader, required String filename, String? attachmentType, String? contentType, bool? addToTransactions})
SentryAttachment.fromScreenshotData(Uint8List bytes)
SentryAttachment.fromUint8List(Uint8List bytes, String fileName, {String? contentType, String? attachmentType, bool? addToTransactions})
Creates an SentryAttachment from a Uint8List
SentryAttachment.fromViewHierarchy(SentryViewHierarchy sentryViewHierarchy)

Properties

addToTransactions → bool
If true, attachment should be added to every transaction. Defaults to false.
final
attachmentType → String
Attachment type. Should be one of the static types declared in SentryAttachment.
final
bytes → FutureOr<Uint8List>
Attachment content. Is loaded while sending this attachment.
no setter
contentType → String?
Attachment content type. Inferred by Sentry if it's not given.
final
filename → String
Attachment file name.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

typeAppleCrashReport → const String
Apple crash report file that creates an error event and is symbolicated.
typeAttachmentDefault → const String
Standard attachment without special meaning.
typeMinidump → const String
Minidump file that creates an error event and is symbolicated. The file should start with the MDMP magic bytes.
typeUnrealContext → const String
XML file containing UE4 crash meta data. During event ingestion, event contexts and extra fields are extracted from this file.
typeUnrealLogs → const String
Plain-text log file obtained from UE4 crashes. During event ingestion, the last logs are extracted into event breadcrumbs.
typeViewHierarchy → const String