SentryEnvelopeItem class

Item holding header information and JSON encoded data.

Constructors

SentryEnvelopeItem(SentryEnvelopeItemHeader header, FutureOr<List<int>> dataFactory(), {Object? originalObject})
SentryEnvelopeItem.fromAttachment(SentryAttachment attachment)
factory
SentryEnvelopeItem.fromClientReport(ClientReport clientReport)
Create a SentryEnvelopeItem which holds the ClientReport data.
factory
SentryEnvelopeItem.fromEvent(SentryEvent event)
Create a SentryEnvelopeItem which holds the SentryEvent data.
factory
SentryEnvelopeItem.fromTransaction(SentryTransaction transaction)
Creates a SentryEnvelopeItem which sends SentryTransaction.
factory
SentryEnvelopeItem.fromUserFeedback(SentryUserFeedback feedback)
Create a SentryEnvelopeItem which sends SentryUserFeedback.
factory

Properties

dataFactory → FutureOr<List<int>> Function()
Create binary data representation of item data.
final
hashCode → int
The hash code for this object.
no setterinherited
Header with info about type and length of data in bytes.
final
originalObject ↔ Object?
The original, non-encoded object, used when direct access to the source data is needed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited