SentryException class

The Exception Interface specifies an exception or error that occurred in a program.

Annotations
  • @immutable

Constructors

SentryException({required String? type, required String? value, String? module, SentryStackTrace? stackTrace, Mechanism? mechanism, int? threadId, dynamic throwable, Map<String, dynamic>? unknown})
const
SentryException.fromJson(Map<String, dynamic> data)
Deserializes a SentryException from JSON Map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mechanism → Mechanism?
An optional object describing the Mechanism that created this exception
final
module → String?
The optional module, or package which the exception type lives in.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → SentryStackTrace?
An optional stack trace object
final
threadId → int?
Represents a SentryThread.id.
final
throwable → dynamic
final
type → String?
Required. The type of exception
final
value → String?
Required. The value of the exception
final

Methods

copyWith({String? type, String? value, String? module, SentryStackTrace? stackTrace, Mechanism? mechanism, int? threadId, dynamic throwable}) → SentryException
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited