SentryLevel class

Severity of the logged Event.

Annotations
  • @immutable

Constructors

SentryLevel.fromName(String name)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
API name of the level as it is encoded in the JSON protocol.
final
ordinal → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDartLogLevel() → int
For use with Dart's log function. These levels are inspired by https://pub.dev/documentation/logging/latest/logging/Level-class.html
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

debug → const SentryLevel
error → const SentryLevel
fatal → const SentryLevel
info → const SentryLevel
warning → const SentryLevel