SentryProxy class

Constructors

SentryProxy({required SentryProxyType type, String? host, int? port, String? user, String? pass})

Properties

hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
pass → String?
final
port → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SentryProxyType
final
user → String?
final

Methods

copyWith({String? host, int? port, SentryProxyType? type, String? user, String? pass}) → SentryProxy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Produces a Map that can be serialized to JSON.
toPacString() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited