SentrySpan class

Inheritance

Constructors

SentrySpan(SentryTracer _tracer, SentrySpanContext _context, Hub _hub, {DateTime? startTimestamp, SentryTracesSamplingDecision? samplingDecision, OnFinishedCallback? finishedCallback, dynamic isRootSpan = false})

Properties

context → SentrySpanContext
Gets the span context.
no setteroverride
data → Map<String, dynamic>
no setter
endTimestamp → DateTime?
Returns the end timestamp if finished
no setteroverride
finished → bool
Returns true if span is finished
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isRootSpan → bool
no setter
origin ↔ String?
Gets the span origin
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingDecision → SentryTracesSamplingDecision?
final
startTimestamp → DateTime
Returns the star timestamp
no setteroverride
status ↔ SpanStatus?
Gets span status.
getter/setter pairoverride
tags → Map<String, String>
no setter
throwable ↔ dynamic
Returns the associated error
getter/setter pairoverride

Methods

finish({SpanStatus? status, DateTime? endTimestamp}) → Future<void>
Sets span timestamp marking this span as finished.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeData(String key) → void
Removes extra data on span or transaction.
override
removeTag(String key) → void
Removes the tag on span or transaction.
override
scheduleFinish() → void
setData(String key, dynamic value) → void
Sets extra data on span or transaction.
override
setMeasurement(String name, num value, {SentryMeasurementUnit? unit}) → void
Set observed measurement for this span or transaction.
override
setTag(String key, String value) → void
Sets the tag on span or transaction.
override
startChild(String operation, {String? description, DateTime? startTimestamp}) → ISentrySpan
Starts a child Span.
override
toBaggageHeader() → SentryBaggageHeader?
Returns the baggage that can be sent as "baggage" header.
override
toJson() → Map<String, dynamic>
toSentryTrace() → SentryTraceHeader
Returns the trace information that could be sent as a sentry-trace header.
override
toString() → String
A string representation of this object.
inherited
traceContext() → SentryTraceContextHeader?
Returns the trace context.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited