SentryUserFeedback class

Annotations
  • @Deprecated('Will be removed in a future version. Use [SentryFeedback] instead')

Constructors

SentryUserFeedback({required SentryId eventId, String? name, String? email, String? comments, Map<String, dynamic>? unknown})
SentryUserFeedback.fromJson(Map<String, dynamic> data)
factory

Properties

comments → String?
Recommended: Comments of the user about what happened.
final
email → String?
Recommended: The name of the user.
final
eventId → SentryId
The eventId of the event to which the user feedback is associated.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
Recommended: The name of the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({SentryId? eventId, String? name, String? email, String? comments}) → SentryUserFeedback
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited