SentryViewHierarchyElement class

Annotations
  • @immutable

Constructors

SentryViewHierarchyElement(String type, {int? depth, String? identifier, double? width, double? height, double? x, double? y, double? z, bool? visible, double? alpha, Map<String, dynamic>? extra})

Properties

alpha → double?
final
children → List<SentryViewHierarchyElement>
final
depth → int?
final
extra → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
identifier → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
visible → bool?
final
width → double?
final
x → double?
final
y → double?
final
z → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Header encoded as JSON
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited