IdleRecordingSentrySpanV2 class final

Recording span with idle behavior built into the span itself.

Inheritance

Constructors

IdleRecordingSentrySpanV2({required SentryId traceId, required String name, required OnSpanEndCallback onSpanEnd, required ClockProvider clock, required DscCreatorCallback dscCreator, required SentryTracesSamplingDecision samplingDecision, required Duration idleTimeout, required Duration finalTimeout, required bool trimEndTimestamp, required SdkLifecycleRegistry lifecycleRegistry})

Properties

attributes Map<String, SentryAttribute>
The read-only view of the attributes of this span using Map.unmodifiable.
no setterinherited
endTimestamp DateTime?
The end timestamp of this span.
no setterinherited
finalTimeout Duration
final
hashCode int
The hash code for this object.
no setterinherited
idleTimeout Duration
final
isEnded bool
Whether this span has ended.
no setterinherited
name String
The name of this span.
getter/setter pairinherited
parentSpan RecordingSentrySpanV2?
The parent span of this span.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingDecision SentryTracesSamplingDecision
The sampling decision for this span's trace.
no setterinherited
segmentSpan RecordingSentrySpanV2
The local root span of this trace segment.
no setterinherited
spanId SpanId
The id of this span.
no setterinherited
startTimestamp DateTime
The start timestamp of this span.
no setterinherited
status SentrySpanStatusV2
The status of this span.
getter/setter pairinherited
traceId SentryId
The id of the trace this span belongs to.
no setterinherited
trimEndTimestamp bool
final

Methods

end({DateTime? endTimestamp}) → void
Ends this span.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAttribute(String key) → void
Removes an attribute on this span with a matching key.
inherited
resetIdleTimer() → void
resolveDsc() SentryTraceContextHeader
The segment's Dynamic Sampling Context (DSC) header.
inherited
setAttribute(String key, SentryAttribute value) → void
Sets an attribute on this span, replacing any existing attribute with the same key.
inherited
setAttributes(Map<String, SentryAttribute> attributes) → void
Sets attributes on this span, replacing existing attributes with the same keys.
inherited
setAttributesIfAbsent(Map<String, SentryAttribute> attributes) → void
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited