SentryDevice class
This describes the device that caused the event.
Constructors
-
SentryDevice({String? name, String? family, String? model, String? modelId, String? arch, double? batteryLevel, SentryOrientation? orientation, String? manufacturer, String? brand, int? screenHeightPixels, int? screenWidthPixels, double? screenDensity, int? screenDpi, bool? online, bool? charging, bool? lowMemory, bool? simulator, int? memorySize, int? freeMemory, int? usableMemory, int? storageSize, int? freeStorage, int? externalStorageSize, int? externalFreeStorage, DateTime? bootTime, int? processorCount, String? cpuDescription, double? processorFrequency, String? deviceType, String? batteryStatus, String? deviceUniqueIdentifier, bool? supportsVibration, bool? supportsAccelerometer, bool? supportsGyroscope, bool? supportsAudio, bool? supportsLocationService, Map<
String, dynamic> ? unknown}) -
SentryDevice.fromJson(Map<
String, dynamic> data) -
Deserializes a SentryDevice from JSON Map.
factory
Properties
- arch ↔ String?
-
The CPU architecture.
getter/setter pair
- batteryLevel ↔ double?
-
If the device has a battery, this can be an floating point value
defining the battery level (in the range 0-100).
getter/setter pair
- batteryStatus ↔ String?
-
Optional. Status of the device's battery.
For example,
Unknown,Charging,Discharging,NotCharging,Full.getter/setter pair - bootTime ↔ DateTime?
-
When the system was booted
getter/setter pair
- brand ↔ String?
-
The brand of the device.
getter/setter pair
- charging ↔ bool?
-
Whether the device was charging or not.
getter/setter pair
- cpuDescription ↔ String?
-
Optional. CPU description. For example,
Intel(R) Core(TM)2 Quad CPU Q6600 @ 2.40GHz.getter/setter pair - deviceType ↔ String?
-
Optional. Kind of device the application is running on.
For example,
Unknown,Handheld,Console,Desktop.getter/setter pair - deviceUniqueIdentifier ↔ String?
-
Optional. Unique device identifier.
This value might only be used if SentryOptions.sendDefaultPii
is enabled.
getter/setter pair
- externalFreeStorage ↔ int?
-
Free size of an attached external storage in bytes
(e.g.: android SDK card).
getter/setter pair
- externalStorageSize ↔ int?
-
Total size of an attached external storage in bytes
(e.g.: android SDK card).
getter/setter pair
- family ↔ String?
-
The family of the device.
getter/setter pair
- freeMemory ↔ int?
-
Free system memory in bytes.
getter/setter pair
- freeStorage ↔ int?
-
Free device storage in bytes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowMemory ↔ bool?
-
Whether the device was low on memory.
getter/setter pair
- manufacturer ↔ String?
-
The manufacturer of the device.
getter/setter pair
- memorySize ↔ int?
-
Total system memory available in bytes.
getter/setter pair
- model ↔ String?
-
The model name. This for instance can be
Samsung Galaxy S3.getter/setter pair - modelId ↔ String?
-
An internal hardware revision to identify the device exactly.
getter/setter pair
- name ↔ String?
-
The name of the device. This is typically a hostname.
getter/setter pair
- online ↔ bool?
-
Whether the device was online or not.
getter/setter pair
- orientation ↔ SentryOrientation?
-
Defines the orientation of a device.
getter/setter pair
- processorCount ↔ int?
-
Optional. Number of "logical processors". For example,
8.getter/setter pair - processorFrequency ↔ double?
-
Optional. Processor frequency in MHz. Note that the actual CPU frequency
might vary depending on current load and power conditions,
especially on low-powered devices like phones and laptops.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenDensity ↔ double?
-
A floating point denoting the screen density.
getter/setter pair
- screenDpi ↔ int?
-
A decimal value reflecting the DPI (dots-per-inch) density.
getter/setter pair
- screenHeightPixels ↔ int?
-
The screen height in pixels. (e.g.:
600,1080).getter/setter pair - screenWidthPixels ↔ int?
-
The screen width in pixels. (e.g.:
800,1920).getter/setter pair - simulator ↔ bool?
-
A flag indicating whether this device is a simulator or an actual device.
getter/setter pair
- storageSize ↔ int?
-
Total device storage in bytes.
getter/setter pair
- supportsAccelerometer ↔ bool?
-
Optional. Is accelerometer available on the device?
getter/setter pair
- supportsAudio ↔ bool?
-
Optional. Is audio available on the device?
getter/setter pair
- supportsGyroscope ↔ bool?
-
Optional. Is gyroscope available on the device?
getter/setter pair
- supportsLocationService ↔ bool?
-
Optional. Is the device capable of reporting its location?
getter/setter pair
- supportsVibration ↔ bool?
-
Optional. Is vibration available on the device?
getter/setter pair
- usableMemory ↔ int?
-
Memory usable for the app in bytes.
getter/setter pair
Methods
-
clone(
) → SentryDevice -
copyWith(
{String? name, String? family, String? model, String? modelId, String? arch, double? batteryLevel, SentryOrientation? orientation, String? manufacturer, String? brand, int? screenHeightPixels, int? screenWidthPixels, double? screenDensity, int? screenDpi, bool? online, bool? charging, bool? lowMemory, bool? simulator, int? memorySize, int? freeMemory, int? usableMemory, int? storageSize, int? freeStorage, int? externalStorageSize, int? externalFreeStorage, DateTime? bootTime, int? processorCount, String? cpuDescription, double? processorFrequency, String? deviceType, String? batteryStatus, String? deviceUniqueIdentifier, bool? supportsVibration, bool? supportsAccelerometer, bool? supportsGyroscope, bool? supportsAudio, bool? supportsLocationService}) → SentryDevice -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Produces a Map that can be serialized to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited