SentryLogger class abstract interface

Interface for emitting custom logs to Sentry.

Access via Sentry.logger.

Properties

fmt SentryLoggerFormatter
Provides formatted logging with template strings.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String body, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a message at DEBUG level.
error(String body, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a message at ERROR level.
fatal(String body, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a message at FATAL level.
info(String body, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a message at INFO level.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trace(String body, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a message at TRACE level.
warn(String body, {Map<String, SentryAttribute>? attributes}) FutureOr<void>
Logs a message at WARN level.

Operators

operator ==(Object other) bool
The equality operator.
inherited