attributes property
The read-only view of the attributes of this span using Map.unmodifiable.
The returned map must not be mutated by callers.
Implementation
@override
Map<String, SentryAttribute> get attributes => _throw();
The read-only view of the attributes of this span using Map.unmodifiable.
The returned map must not be mutated by callers.
@override
Map<String, SentryAttribute> get attributes => _throw();